<?php

namespace Teknisa\CMP\Modules\Cadastros\Services;

use Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Doctrine\ORM\EntityManager;

class Cmp00500RegiaoNaoAtendidaPeloFornecedorService {
    
    protected $crudService;
    protected $entityManager;
    protected $connection;
    protected $environment;
    protected $dataSourceManager;
    protected $newCode;

    public function __construct($crudService, $entityManager,$connection, $environment, $dataSourceManager, $newCode) {
        $this->crudService       = $crudService;
        $this->entityManager     = $entityManager;
        $this->connection        = $connection;
        $this->environment       = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->newCode           = $newCode;
    }
    /********************
     *      INSERTS     *
     * ******************/
    public function insertRegiao($row){    
        try {
            $sql = "INSERT INTO REFOREG(CDREGIAO, CDFORNECED) VALUES (:CDREGIAO, :CDFORNECED)";
            $params = array(
                'CDREGIAO'     => $row['CDREGIAO'],
                'CDFORNECED'   => $row['CDFORNECED']
            );
            
          	$query = $this->connection->prepare($sql);
        	$query->execute($params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir região.');
        }
    }
    
    public function incluiFilNAtend($row){    
        try {
            $sql = "INSERT INTO REFORFIL (CDFORNECED, CDFILIAL, NRORG) (SELECT :CDFORNECED, CDFILIAL, NRORG FROM FILIAL WHERE FILIAL.CDREGIAO = :CDREGIAO AND FILIAL.NRORG = :NRORG)";
            $params = array(
                'CDREGIAO'     => $row['CDREGIAO'],
                'CDFORNECED'   => $row['CDFORNECED'],
                'NRORG'        => $this->environment->getNrorg()
            );
            
          	$query = $this->connection->prepare($sql);
        	$query->execute($params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir região.');
        }
    }
    
    public function insertExportation($row){    
        try {
            $sql = "INSERT INTO REFOREG(CDREGIAO, CDFORNECED) SELECT REFOREG.CDREGIAO, FORNECEDOR.CDFORNECED FROM REFOREG, FORNECEDOR WHERE REFOREG.CDFORNECED = :P_CDFORNORG AND (INSTR(:P_CDFORNDES, FORNECEDOR.CDFORNECED) <> 0 OR :P_CDFORNDES = 'T') AND (INSTR(:P_CDREG, REFOREG.CDREGIAO) <> 0 OR :P_CDREG = 'T') AND NOT EXISTS (SELECT A.CDREGIAO FROM REFOREG A WHERE A.CDREGIAO = REFOREG.CDREGIAO AND A.CDFORNECED = FORNECEDOR.CDFORNECED)";
            $params = array(
                'P_CDFORNORG' => $row['CDFORNECEDORIG'],
                'P_CDFORNDES' => $row['CDFORNECEDDEST'],
                'P_CDREG'     => $row['CDREGIAO']
            );
           	$query = $this->connection->prepare($sql);
        	$query->execute($params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir região.!');
        }
    }

    /*
    /********************
     *      DELETES     *
     * ******************/
     
    
    public function deleteRegiao($row) {
        try {
            $sql = "DELETE FROM REFOREG WHERE CDREGIAO = :OLD_CDREGIAO AND CDFORNECED = :OLD_CDFORNECED";
            $params = array(
                'OLD_CDFORNECED' => $row['CDFORNECED'],
                'OLD_CDREGIAO'   => $row['CDREGIAO']
            );
          	$query = $this->connection->prepare($sql);
        	$query->execute($params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao deletar região.');
        }
    }
    
    /********************
     *      SELECTS     *
     * ******************/
    public function findRegiao($row) {
        $sql = 'SELECT CDREGIAO FROM REFOREG WHERE(CDFORNECED = :P_CDFORNECED) AND (CDREGIAO = :P_CDREGIAO)';
        $params = array (
            'P_CDFORNECED'  => $row['CDFORNECED'],
            'P_CDREGIAO'    => $row['CDREGIAO']
        );
 	    $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    public function verificaFilialReg($row) {
        $sql = 'SELECT FILIAL.CDFILIAL, FILIAL.CDREGIAO FROM FILIAL WHERE(FILIAL.CDREGIAO = :P_CDREGIAO) AND ((EXISTS (SELECT CDFORNECED FROM REFORFIL WHERE REFORFIL.CDFORNECED = :P_CDFORNECED AND REFORFIL.CDFILIAL = FILIAL.CDFILIAL AND REFORFIL.CDPERIENTR IS NOT NULL)) OR (NOT EXISTS (SELECT CDFORNECED FROM REFORFIL WHERE REFORFIL.CDFORNECED = :P_CDFORNECED AND REFORFIL.CDFILIAL = FILIAL.CDFILIAL)))';
        $params = array (
            'P_CDFORNECED'  => $row['CDFORNECED'],
            'P_CDREGIAO'    => $row['CDREGIAO']
        );
 	    $query = $this->connection->prepare($sql);
        $query->execute($params);
          return $query->fetchAll();
    }
    public function verificaExportacao($row) {
        $sql = "SELECT FILIAL.CDFILIAL||' - '|| FILIAL.NMFILIAL AS FILIAL, FILIAL.CDREGIAO||' - '|| REGIAO.NMREGIAO AS REGIAO, FORNECEDOR.NRINSJURFORN FORNECEDOR, FORNECEDOR.NMFANTFORN, FORNECEDOR.IDTPIJURFORN FROM FORNECEDOR, REGIAO, FILIAL WHERE(REGIAO.CDREGIAO = FILIAL.CDREGIAO) AND (INSTR(:P_CDREGIAO, FILIAL.CDREGIAO)<>0 OR :P_CDREGIAO = 'T') AND (INSTR(:P_CDFORNECED, FORNECEDOR.CDFORNECED)<>0 OR :P_CDFORNECED = 'T') AND ((EXISTS (SELECT CDFORNECED FROM REFORFIL WHERE REFORFIL.CDFORNECED = FORNECEDOR.CDFORNECED AND REFORFIL.CDFILIAL = FILIAL.CDFILIAL AND REFORFIL.CDPERIENTR IS NOT NULL)) OR (NOT EXISTS (SELECT CDFORNECED FROM REFORFIL WHERE REFORFIL.CDFORNECED = FORNECEDOR.CDFORNECED AND REFORFIL.CDFILIAL = FILIAL.CDFILIAL))) ORDER BY FORNECEDOR.NRINSJURFORN, FILIAL.CDREGIAO, FILIAL.CDFILIAL";
        $params = array (
            'P_CDFORNECED'  => $row['CDFORNECEDDEST'],
            'P_CDREGIAO'    => $row['CDREGIAO']
        );
 	    $query = $this->connection->prepare($sql);
        $query->execute($params);
        return $query->fetchAll();
    }
    
    /********************
     *      DELETS     *
     * ******************/
    
     public function excluiFiliAtend($row){    
        try {
            $sql = "DELETE FROM REFORFIL WHERE (CDFORNECED = :CDFORNECED) AND (EXISTS (SELECT CDFILIAL FROM FILIAL WHERE FILIAL.CDFILIAL = REFORFIL.CDFILIAL AND FILIAL.CDREGIAO = :CDREGIAO AND FILIAL.NRORG = :NRORG))";
            $params = array(
                'CDREGIAO'     => $row['CDREGIAO'],
                'CDFORNECED'   => $row['CDFORNECED'],
                'NRORG'        => $this->environment->getNrorg()
                
            );
            
          	$query = $this->connection->prepare($sql);
        	$query->execute($params);
        }
        catch (Exception $e) {
            throw new \Exception('Erro ao inserir região.');
        }
    }
}